PyGranta metapackage
====================
|pyansys| |python| |pypi| |GH-CI| |MIT| |black| |pre-commit|

.. |pyansys| image:: https://img.shields.io/badge/Py-Ansys-ffc107.svg?logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAABDklEQVQ4jWNgoDfg5mD8vE7q/3bpVyskbW0sMRUwofHD7Dh5OBkZGBgW7/3W2tZpa2tLQEOyOzeEsfumlK2tbVpaGj4N6jIs1lpsDAwMJ278sveMY2BgCA0NFRISwqkhyQ1q/Nyd3zg4OBgYGNjZ2ePi4rB5loGBhZnhxTLJ/9ulv26Q4uVk1NXV/f///////69du4Zdg78lx//t0v+3S88rFISInD59GqIH2esIJ8G9O2/XVwhjzpw5EAam1xkkBJn/bJX+v1365hxxuCAfH9+3b9/+////48cPuNehNsS7cDEzMTAwMMzb+Q2u4dOnT2vWrMHu9ZtzxP9vl/69RVpCkBlZ3N7enoDXBwEAAA+YYitOilMVAAAAAElFTkSuQmCC
   :target: https://docs.pyansys.com/
   :alt: PyAnsys

.. |python| image:: https://img.shields.io/pypi/pyversions/pygranta?logo=pypi
   :target: https://pypi.org/project/pygranta/
   :alt: Python

.. |pypi| image:: https://img.shields.io/pypi/v/pygranta.svg?logo=python&logoColor=white
   :target: https://pypi.org/project/pygranta/
   :alt: PyPI

.. |GH-CI| image:: https://github.com/ansys/pygranta/actions/workflows/ci-build.yml/badge.svg
   :target: https://github.com/ansys/pygranta/actions/workflows/ci-build.yml
   :alt: GH-CI

.. |MIT| image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://opensource.org/licenses/MIT
   :alt: MIT

.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg?style=flat
   :target: https://github.com/psf/black
   :alt: Black

.. |pre-commit| image:: https://results.pre-commit.ci/badge/github/ansys/pygranta/main.svg
   :target: https://results.pre-commit.ci/latest/github/ansys/pygranta/main
   :alt: pre-commit.ci status

Welcome to the PyGranta metapackage repository. The ``pygranta`` metapackage
provides a single package of collected PyGranta packages that ensures compatibility
of these packages amongst themselves and the Granta MI release that they are linked to.

The ``pygranta`` metapackage ensures compatibility between these PyGranta packages:

- `BoM Analytics <https://bomanalytics.grantami.docs.pyansys.com/>`_: Pythonic interface to the Ansys Granta MI BoM Analytics services.
- `RecordLists <https://recordlists.grantami.docs.pyansys.com/>`_: Pythonic interface to the Ansys Granta MI Lists API.
- `JobQueue <https://jobqueue.grantami.docs.pyansys.com/>`_: Pythonic interface to the Ansys Granta MI JobQueue API.
- `serverapi-openapi <https://github.com/ansys/grantami-serverapi-openapi/>`_: Autogenerated client library for the Ansys Granta MI Server API Services.

The PyGranta metapackage installs these core modules and their dependencies:

- `BoM Analytics`_
- `RecordLists`_
- `JobQueue`_
- `serverapi-openapi`_

Documentation
-------------

Documentation for the latest stable release of PyGranta is hosted at
`PyGranta documentation <https://grantami.docs.pyansys.com/version/stable/index.html#>`_.
The documentation has four sections:

- `Getting started <https://grantami.docs.pyansys.com/version/stable/getting_started.html#>`_: Describes
  how to install PyGranta in user mode.
- `User guide <https://grantami.docs.pyansys.com/version/stable/user_guide.html>`_: Describes how to
  use PyGranta.
- `API reference <https://grantami.docs.pyansys.com/version/stable/api.html>`_: Provides API member descriptions
  and usage examples.
- `Examples <https://grantami.docs.pyansys.com/version/stable/examples.html>`_: Provides examples showing
  end-to-end workflows for using PyGranta.


License and acknowledgments
---------------------------
All PyGranta libraries are licensed under the MIT license.

PyGranta libraries make no commercial claim over Ansys whatsoever.
These libraries extend the functionality of Ansys products by
adding Python interfaces to legally obtained software products
without changing the core behaviors or licenses of the original
software.

For more information on Ansys products, visit the `Ansys website <https://www.ansys.com/>`_.
